@@ -1,10 +1,14 @@
-# Copyrights 2006-2017 by [Mark Overmeer].
+# Copyrights 2006-2024 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
-package XML::Compile::Translate::Reader;
-use vars '$VERSION';
-$VERSION = '1.58';
+# Pod stripped from pm file by OODoc 2.03.
+# This code is part of distribution XML-Compile.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+
+package XML::Compile::Translate::Reader;{
+our $VERSION = '1.64';
+}
 
 use base 'XML::Compile::Translate';
 
@@ -12,9 +16,10 @@ use strict;
 use warnings;
 no warnings 'once', 'recursion';
 
-use Log::Report 'xml-compile', syntax => 'SHORT';
-use List::Util   qw/first/;
-use Scalar::Util qw/weaken blessed/;
+use Log::Report       'xml-compile';
+
+use List::Util         qw/first/;
+use Scalar::Util       qw/weaken blessed/;
 
 use XML::Compile::Util qw/pack_type odd_elements type_of_node SCHEMA2001i/;
 use XML::Compile::Iterator ();
@@ -580,6 +585,7 @@ sub makeElementAbstract
 # Be warned that the location reported in 'path' may not be the actual
 # location, caused by the cashing of compiled schema components.  The
 # path you see is the first path where that element was encountered.
+
 sub _not_processed($$)
 {   my ($child, $path) = @_;
     error __x"element `{name}' not processed for {path} at {where}"
@@ -589,7 +595,7 @@ sub _not_processed($$)
 
 sub makeComplexElement
 {   my ($self, $path, $tag, $elems, $attrs, $attrs_any,undef,$is_nillable) = @_;
-#my @e = @$elems; my @a = @$attrs;
+my @e = @$elems; my @a = @$attrs;
 
     my @elems = odd_elements @$elems;
     my @attrs = (odd_elements(@$attrs), @$attrs_any);
@@ -613,6 +619,9 @@ sub makeComplexElement
           my $node    = $tree->node;
           my %complex = ((map $_->($tree), @elems), (map $_->($node), @attrs));
 
+#if($tree->currentChild)
+#{   warn "COMPLEX ELEMS($tag) @e;@a";
+#}
           _not_processed $tree->currentChild, $path
               if $tree->currentChild;
 
@@ -646,7 +655,7 @@ sub makeTaggedElement
 {   my ($self, $path, $tag, $st, $attrs, $attrs_any,undef,$is_nillable) = @_;
     my @attrs = (odd_elements(@$attrs), @$attrs_any);
 
-    sub { my $tree   = shift or return ();
+    sub { my $tree   = shift // return ();
           my $simple = $is_nillable && ref $tree && $tree->nodeNil ? 'NIL' : $st->($tree);
           ref $tree or return ($tag => {_ => $simple});
           my $node   = $tree->node;
@@ -663,8 +672,10 @@ sub makeMixedElement
 {   my ($self, $path, $tag, $elems, $attrs, $attrs_any,undef,$is_nillable) = @_;
     my @attrs = (odd_elements(@$attrs), @$attrs_any);
     my $mixed = $self->{mixed_elements}
-         or panic "how to handle mixed?";
-$is_nillable and panic "nillable mixed not yet supported";
+        or panic "how to handle mixed?";
+
+    $is_nillable
+        and panic "nillable mixed not yet supported";
 
       ref $mixed eq 'CODE'
     ? sub { my $tree = shift or return;
@@ -711,7 +722,7 @@ sub makeSimpleElement
 {   my ( $self, $path, $tag, $st, undef, undef, $comptype, $is_nillable) = @_;
 
       $is_nillable
-    ? sub { my $tree  = shift or return $st->(undef);
+    ? sub { my $tree  = shift // return $st->(undef);
             my $value = (ref $tree && $tree->nodeNil) ? 'NIL' : $st->($tree);
             defined $value ? ($tag => $value) : ();
           }
@@ -783,14 +794,12 @@ sub makeBuiltin
 
 sub makeList
 {   my ($self, $path, $st) = @_;
-    sub { my $tree = shift;
-          defined $tree or return undef;
+    sub { my $tree = shift // return undef;
           my $node
              = UNIVERSAL::isa($tree, 'XML::LibXML::Node') ? $tree
              : ref $tree ? $tree->node : undef;
           my $v = ref $tree ? $tree->textContent : $tree;
-          my @v = grep defined, map $st->($_, $node), split " ", $v;
-          @v ? \@v : undef;
+          [ grep defined, map $st->($_, $node), split " ", $v ];
         };
 }
 
@@ -801,7 +810,7 @@ sub makeFacetsList
 
     # enumeration and pattern are probably rare
     @e or return sub {
-        my $values = $st->(@_) or return;
+        my $values = $st->(@_) // return;
         $_->($values) for @l;
         $values;
     };
@@ -809,7 +818,7 @@ sub makeFacetsList
     sub { defined $_[0] or return undef;
         my $list = ref $_[0] ? $_[0]->textContent : $_[0];
         $_->($list) for @e;
-        my $values = $st->($_[0]) or return;
+        my $values = $st->($_[0]) // return;
         $_->($values) for @l;
         $values;
     };
@@ -834,8 +843,7 @@ sub makeFacets
 		{   return if !defined $v;
             $v = $_->($v) for @$early;
         }
-        $v = $st->($v);
-		defined $v or return undef;
+        $v = $st->($v) // return undef;
         $v = $_->($v) for @$late;
         $v;
     };
@@ -843,9 +851,9 @@ sub makeFacets
 
 sub makeUnion
 {   my ($self, $path, @types) = @_;
-    sub { my $tree = shift or return undef;
+    sub { my $tree = shift // return undef;
           for(@types) { my $v = try { $_->($tree) }; $@ or return $v }
-          my $text = $tree->textContent;
+          my $text = ref $tree ? $tree->textContent : $tree;
 
           substr $text, 20, -5, '...' if length($text) > 50;
           error __x"no match for `{text}' in union at {path}"
